import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CostExplorerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CostExplorerClient";
import { GetCostForecastRequest, GetCostForecastResponse } from "../models/models_0";
/**
 * @public
 *
 * The input for {@link GetCostForecastCommand}.
 */
export interface GetCostForecastCommandInput extends GetCostForecastRequest {
}
/**
 * @public
 *
 * The output of {@link GetCostForecastCommand}.
 */
export interface GetCostForecastCommandOutput extends GetCostForecastResponse, __MetadataBearer {
}
/**
 * @public
 * <p>Retrieves a forecast for how much Amazon Web Services predicts that you will spend over
 *       the forecast time period that you select, based on your past costs. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CostExplorerClient, GetCostForecastCommand } from "@aws-sdk/client-cost-explorer"; // ES Modules import
 * // const { CostExplorerClient, GetCostForecastCommand } = require("@aws-sdk/client-cost-explorer"); // CommonJS import
 * const client = new CostExplorerClient(config);
 * const command = new GetCostForecastCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @param GetCostForecastCommandInput - {@link GetCostForecastCommandInput}
 * @returns {@link GetCostForecastCommandOutput}
 * @see {@link GetCostForecastCommandInput} for command's `input` shape.
 * @see {@link GetCostForecastCommandOutput} for command's `response` shape.
 * @see {@link CostExplorerClientResolvedConfig | config} for CostExplorerClient's `config` shape.
 *
 * @throws {@link DataUnavailableException} (client fault)
 *  <p>The requested data is unavailable.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You made too many calls in a short period of time. Try again later.</p>
 *
 *
 */
export declare class GetCostForecastCommand extends $Command<GetCostForecastCommandInput, GetCostForecastCommandOutput, CostExplorerClientResolvedConfig> {
    readonly input: GetCostForecastCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: GetCostForecastCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CostExplorerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetCostForecastCommandInput, GetCostForecastCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
