import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CostExplorerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CostExplorerClient";
import { GetUsageForecastRequest, GetUsageForecastResponse } from "../models/models_0";
/**
 * @public
 *
 * The input for {@link GetUsageForecastCommand}.
 */
export interface GetUsageForecastCommandInput extends GetUsageForecastRequest {
}
/**
 * @public
 *
 * The output of {@link GetUsageForecastCommand}.
 */
export interface GetUsageForecastCommandOutput extends GetUsageForecastResponse, __MetadataBearer {
}
/**
 * @public
 * <p>Retrieves a forecast for how much Amazon Web Services predicts that you will use
 *       over the forecast time period that you select, based on your past usage. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CostExplorerClient, GetUsageForecastCommand } from "@aws-sdk/client-cost-explorer"; // ES Modules import
 * // const { CostExplorerClient, GetUsageForecastCommand } = require("@aws-sdk/client-cost-explorer"); // CommonJS import
 * const client = new CostExplorerClient(config);
 * const command = new GetUsageForecastCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @param GetUsageForecastCommandInput - {@link GetUsageForecastCommandInput}
 * @returns {@link GetUsageForecastCommandOutput}
 * @see {@link GetUsageForecastCommandInput} for command's `input` shape.
 * @see {@link GetUsageForecastCommandOutput} for command's `response` shape.
 * @see {@link CostExplorerClientResolvedConfig | config} for CostExplorerClient's `config` shape.
 *
 * @throws {@link DataUnavailableException} (client fault)
 *  <p>The requested data is unavailable.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You made too many calls in a short period of time. Try again later.</p>
 *
 * @throws {@link UnresolvableUsageUnitException} (client fault)
 *  <p>Cost Explorer was unable to identify the usage unit. Provide
 *                 <code>UsageType/UsageTypeGroup</code> filter selections that contain matching units,
 *             for example: <code>hours</code>.</p>
 *
 *
 */
export declare class GetUsageForecastCommand extends $Command<GetUsageForecastCommandInput, GetUsageForecastCommandOutput, CostExplorerClientResolvedConfig> {
    readonly input: GetUsageForecastCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: GetUsageForecastCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CostExplorerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetUsageForecastCommandInput, GetUsageForecastCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
